@@ -275,6 +275,101 @@ def test_user_active(test_options):
         d.user_delete(email)
 
 
+def test_user_trust_level(test_options):
+    email = 'user@example.com'
+    d = DiscourseTest(test_options).connect()
+    try:
+        password = 'dashkeedfakojfiesMob'
+        username = 'MYUSERNAME'
+        kwargs = {
+            'username': username,
+            'password': password,
+            'active': 'true',
+        }
+        _, _ = d.user_create(email, **kwargs)
+
+        d.args.dry_run = True
+        before0, after0 = d.user_trust_level(email, '1')
+        assert before0['trust_level'] == '0'
+        assert after0['trust_level'] == '1'
+
+        d.args.dry_run = False
+        before0, after0 = d.user_trust_level(email, '1')
+        assert before0['trust_level'] == '0'
+        assert after0['trust_level'] == '1'
+
+        before1, after1 = d.user_trust_level(email, '1')
+        assert after0 == before1
+        assert before1 == after1
+
+        with pytest.raises(discourse.DiscourseErrorUserTrustLevel):
+            d.user_trust_level(email, 'invalid')
+    finally:
+        d.user_delete(email)
+
+
+def test_user_create_trust_level_0(test_options):
+    email = 'user@example.com'
+    d = DiscourseTest(test_options).connect()
+    try:
+        password = 'dashkeedfakojfiesMob'
+        username = 'MYUSERNAME'
+        kwargs = {
+            'username': username,
+            'password': password,
+        }
+        before, after = d.user_create(email, **kwargs)
+        assert before is None
+        assert after['trust_level'] == '0'
+    finally:
+        d.user_delete(email)
+
+
+def test_user_create_trust_level_1(test_options):
+    email = 'user@example.com'
+    d = DiscourseTest(test_options).connect()
+    try:
+        password = 'dashkeedfakojfiesMob'
+        username = 'MYUSERNAME'
+        trust_level = '1'
+        kwargs = {
+            'username': username,
+            'password': password,
+            'trust_level': trust_level,
+        }
+        before, after = d.user_create(email, **kwargs)
+        assert before is None
+        assert after['trust_level'] == trust_level
+
+    finally:
+        d.user_delete(email)
+
+
+def test_user_delete_and_block(test_options):
+    d = DiscourseTest(test_options).connect()
+    email = 'banned0@example.com'
+    password = 'dashkeedfakojfiesMob'
+    username = 'MYUSERNAME'
+    kwargs = {
+        'username': username,
+        'password': password,
+    }
+    d.emails_allow(email)
+    assert d.emails_check(email) is True
+    before0, after0 = d.user_create(email, **kwargs)
+    assert before0 is None
+    assert after0['email'] == email
+    assert after0['username'] == username
+
+    email_similar = 'banned1@example.com'
+    assert d.emails_check(email_similar) is True
+    assert d.user_delete(email, block_email=True)['id'] == after0['id']
+    assert any([e["email"] == email for e in d.emails_screened()]) is True
+    assert d.emails_check(email) is False
+    assert d.emails_check(email_similar) is False
+    assert d.emails_allow(email) is True
+
+
 def test_user_duplicate(test_options):
     d = DiscourseTest(test_options).connect()
     first_email = 'someuser@some.com'
